"""
Declares enumerations for various model properties.
"""
from bokeh.core.enums import enumeration

ace_themes = enumeration(
    'ambiance', 'chaos', 'chrome', 'cloud9_day', 'cloud9_night', 'clouds',
    'clouds_midnight', 'cobalt', 'crimson_editor', 'dawn', 'dracula',
    'dreamweaver', 'eclipse', 'github', 'github_dark',
    'github_light_default', 'gob', 'gruvbox', 'idle_fingers',
    'iplastic', 'katzenmilch', 'kr_theme', 'kuroir', 'merbivore',
    'merbivore_soft', 'mono_industrial', 'monokai', 'nord_dark',
    'one_dark', 'pastel_on_dark', 'solarized_dark', 'solarized_light',
    'sqlserver', 'terminal', 'textmate', 'tomorrow', 'tomorrow_night',
    'tomorrow_night_blue', 'tomorrow_night_bright',
    'tomorrow_night_eighties', 'twilight', 'vibrant_ink', 'xcode',
)
